pub struct AnalyzerConfig {Show 22 fields
pub body: String,
pub skip_ci: bool,
pub skip_chore: bool,
pub skip_doc: bool,
pub skip_test: bool,
pub skip_style: bool,
pub skip_refactor: bool,
pub skip_perf: bool,
pub skip_revert: bool,
pub skip_miscellaneous: bool,
pub skip_merge_commits: bool,
pub include_author: bool,
pub tag_prefix: Option<String>,
pub release_link_base_url: Option<Url>,
pub compare_link_base_url: Option<Url>,
pub prerelease: Option<PrereleaseConfig>,
pub release_commit_matcher: Option<Regex>,
pub breaking_always_increment_major: bool,
pub features_always_increment_minor: bool,
pub custom_major_increment_regex: Option<String>,
pub custom_minor_increment_regex: Option<String>,
pub commit_modifiers: CommitModifiers,
}Expand description
Configuration for commit analysis and changelog generation.
Fields
body: StringTera template string for changelog body format.
skip_ci: boolSkips including ci commits in changelog (default: false)
skip_chore: boolSkips including chore commits in changelog (default: false)
skip_doc: boolSkips including doc commits in changelog (default: false)
skip_test: boolSkips including test commits in changelog (default: false)
skip_style: boolSkips including style commits in changelog (default: false)
skip_refactor: boolSkips including refactor commits in changelog (default: false)
skip_perf: boolSkips including perf commits in changelog (default: false)
skip_revert: boolSkips including revert commits in changelog (default: false)
skip_miscellaneous: boolSkips including miscellaneous commits in changelog (default: false)
skip_merge_commits: boolSkips including merge commits in changelog (default: true)
Includes commit author in default body template (default: false)
tag_prefix: Option<String>Optional prefix for package tags.
release_link_base_url: Option<Url>Base URL for release links in changelog.
compare_link_base_url: Option<Url>Base URL for comparing releases and showing diffs
prerelease: Option<PrereleaseConfig>Prerelease settings (if enabled).
release_commit_matcher: Option<Regex>regex to match and exclude release commits
breaking_always_increment_major: boolAlways increments major version on breaking commits
features_always_increment_minor: boolAlways increments minor version on feature commits
custom_major_increment_regex: Option<String>Custom commit type regex matcher to increment major version
custom_minor_increment_regex: Option<String>Custom commit type regex matcher to increment minor version
commit_modifiers: CommitModifiersCustom commit modifiers to skip commit shas or reword commit messages when generating changelog content