pub struct SubPackage {
pub name: String,
pub path: String,
pub release_type: Option<ReleaseType>,
}Expand description
Sub-package definition allowing grouping of packages under a parent package configuration. Sub-packages share changelog, tag, and release with the parent package definition but receive independent manifest version file updates according to their defined release type
Fields
name: StringName for this sub-package (default derived from path if not provided). For proper manifest version file updates this should match the canonical name field in the release_type manifest file. i.e. name = “…” in Cargo.toml or “name”: “…” in package.json
path: StringPath to the subpackage directory relative to the workspace_root of the parent package
release_type: Option<ReleaseType>ReleaseType type for determining which version files to update