pub struct Config {
pub base_branch: Option<String>,
pub first_release_search_depth: usize,
pub tag_search_depth: usize,
pub separate_pull_requests: bool,
pub prerelease: PrereleaseConfig,
pub auto_start_next: Option<bool>,
pub breaking_always_increment_major: bool,
pub features_always_increment_minor: bool,
pub custom_major_increment_regex: Option<String>,
pub custom_minor_increment_regex: Option<String>,
pub changelog: ChangelogConfig,
pub packages: Vec<PackageConfig>,
}Expand description
Configuration properties for releasaurus.toml
Fields
base_branch: Option<String>The base branch to target for release PRs, tagging, and releases defaults to default_branch for repository
first_release_search_depth: usizeMaximum number of commits to search for the first release when no tags exist
tag_search_depth: usizeMaximum number of tags to pull when searching for previous releases. Set to 0 to search all tags
separate_pull_requests: boolGenerates different release PRs for each package defined in config
prerelease: PrereleaseConfigGlobal prerelease configuration (suffix + strategy). Packages can override this configuration
auto_start_next: Option<bool>Global config to auto start next release for all packages. Packages can override this configuration
breaking_always_increment_major: boolAlways increments major version on breaking commits
features_always_increment_minor: boolAlways increments minor version on feature commits
custom_major_increment_regex: Option<String>Custom regex pattern matched against commit messages to trigger a
major version bump. This is additive — breaking change commits always
trigger major bumps regardless of this setting. In TOML double-quoted
strings, escape backslashes (e.g. "\\[BREAKING\\]" matches
[BREAKING]).
custom_minor_increment_regex: Option<String>Custom regex pattern matched against commit messages to trigger a
minor version bump. This is additive — feat: commits always trigger
minor bumps regardless of this setting. In TOML double-quoted strings,
escape backslashes (e.g. "\\[FEATURE\\]" matches [FEATURE]).
changelog: ChangelogConfigChangelog generation settings.
packages: Vec<PackageConfig>Packages to manage in this repository (supports monorepos)
Implementations
Sourceimpl Config
impl Config
pub fn base_branch(&self) -> Result<String>
pub fn auto_start_next(&self, package: &PackageConfig) -> bool