pub struct ResolvedPackage {
pub name: String,
pub normalized_workspace_root: PathBuf,
pub normalized_full_path: PathBuf,
pub release_type: ReleaseType,
pub tag_prefix: String,
pub sub_packages: Vec<ResolvedPackage>,
pub prerelease: Option<PrereleaseConfig>,
pub auto_start_next: bool,
pub normalized_additional_paths: Vec<PathBuf>,
pub compiled_additional_manifests: Vec<CompiledAdditionalManifest>,
pub analyzer_config: AnalyzerConfig,
}Expand description
A fully resolved package configuration ready for processing.
This type represents a package after all configuration sources have been merged and validated. All optional values have been resolved to concrete values, paths have been normalized, and complex configurations (like analyzer config) have been built.
Fields
name: Stringnormalized_workspace_root: PathBufnormalized_full_path: PathBufrelease_type: ReleaseTypetag_prefix: Stringsub_packages: Vec<ResolvedPackage>prerelease: Option<PrereleaseConfig>auto_start_next: boolnormalized_additional_paths: Vec<PathBuf>compiled_additional_manifests: Vec<CompiledAdditionalManifest>analyzer_config: AnalyzerConfigTrait Implementations
Sourceimpl Clone for ResolvedPackage
impl Clone for ResolvedPackage
Sourcefn clone(&self) -> ResolvedPackage
fn clone(&self) -> ResolvedPackage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ResolvedPackage
impl RefUnwindSafe for ResolvedPackage
impl Send for ResolvedPackage
impl Sync for ResolvedPackage
impl Unpin for ResolvedPackage
impl UnsafeUnpin for ResolvedPackage
impl UnwindSafe for ResolvedPackage