pub struct PackageConfig {Show 14 fields
pub name: String,
pub workspace_root: String,
pub path: String,
pub release_type: Option<ReleaseType>,
pub tag_prefix: Option<String>,
pub sub_packages: Option<Vec<SubPackage>>,
pub prerelease: Option<PrereleaseConfig>,
pub auto_start_next: Option<bool>,
pub additional_paths: Option<Vec<String>>,
pub additional_manifest_files: Option<Vec<AdditionalManifestSpec>>,
pub breaking_always_increment_major: Option<bool>,
pub features_always_increment_minor: Option<bool>,
pub custom_major_increment_regex: Option<String>,
pub custom_minor_increment_regex: Option<String>,
}Expand description
Package configuration for multi-package repositories and monorepos
Fields
name: StringName for this package (default derived from path if not provided). For proper manifest version file updates this should match the canonical name field in the release_type manifest file. i.e. name = “…” in Cargo.toml or “name”: “…” in package.json
workspace_root: StringPath to the workspace root directory for this package relative to the repository root
path: StringPath to package directory relative to workspace_root
release_type: Option<ReleaseType>ReleaseType type for determining which version files to update
tag_prefix: Option<String>Git tag prefix for this package (e.g., “v” or “api-v”)
sub_packages: Option<Vec<SubPackage>>Groups sub-packages under a single release. Each will share changelog, tag, and release, but will receive independent manifest version updates according to their type
prerelease: Option<PrereleaseConfig>Optional prerelease configuration that overrides global settings
auto_start_next: Option<bool>Auto starts next release for this package by performing a patch version update to version files and pushing a “chore” commit to the base_branch
additional_paths: Option<Vec<String>>Additional directory paths to include commits from
additional_manifest_files: Option<Vec<AdditionalManifestSpec>>Additional paths to generic version manifest files to update. Paths must be relative to the package path. Accepts either simple string paths or full config objects with custom regex patterns.
breaking_always_increment_major: Option<bool>Always increments major version on breaking commits
features_always_increment_minor: Option<bool>Always increments minor version on feature commits
custom_major_increment_regex: Option<String>Custom regex pattern matched against commit messages to trigger a
major version bump. This is additive — breaking change commits always
trigger major bumps regardless of this setting. In TOML double-quoted
strings, escape backslashes (e.g. "\\[BREAKING\\]" matches
[BREAKING]).
custom_minor_increment_regex: Option<String>Custom regex pattern matched against commit messages to trigger a
minor version bump. This is additive — feat: commits always trigger
minor bumps regardless of this setting. In TOML double-quoted strings,
escape backslashes (e.g. "\\[FEATURE\\]" matches [FEATURE]).
Implementations
Sourceimpl PackageConfig
impl PackageConfig
pub fn tag_prefix(&self) -> Result<String>